@@ -13,18 +13,18 @@ class LengthKeyParameter(ParameterWithDOP):
     The other parameter references the length key parameter using a ParamLengthInfoType as .diag_coded_type.
 
     LengthKeyParameters are decoded the same as ValueParameters.
-    The main difference to ValueParameters is that a LengthKeyParameter has an `.id` attribute
+    The main difference to ValueParameters is that a LengthKeyParameter has an `.odx_id` attribute
     and its DOP must be a simple DOP with PHYSICAL-TYPE/BASE-DATA-TYPE="A_UINT32".
     """
 
     def __init__(self,
                  short_name,
-                 id,
+                 odx_id,
                  dop_ref=None,
                  dop_snref=None,
                  long_name=None,
                  byte_position=None,
-                 bit_position=0,
+                 bit_position=None,
                  semantic=None,
                  description=None):
         super().__init__(short_name,
@@ -36,7 +36,7 @@ class LengthKeyParameter(ParameterWithDOP):
                          bit_position=bit_position,
                          semantic=semantic,
                          description=description)
-        self.id = id
+        self.odx_id = odx_id
 
     def is_required(self):
         return False
@@ -52,6 +52,6 @@ class LengthKeyParameter(ParameterWithDOP):
                             f" must be specified.")
 
         # Set the value of the length key in the length key dict.
-        encode_state.length_keys[self.id] = physical_value
+        encode_state.length_keys[self.odx_id] = physical_value
 
         return super(ParameterWithDOP, self).encode_into_pdu(encode_state)
