@@ -2,7 +2,7 @@
 # Copyright (c) 2022 MBition GmbH
 
 import math
-from typing import TYPE_CHECKING, Any, List, Dict, Iterable, OrderedDict, Tuple, Union
+from typing import TYPE_CHECKING, Any, Optional, List, Dict, Iterable, ByteString, OrderedDict, Tuple, Union
 import warnings
 
 from .utils import short_name_as_id
@@ -23,6 +23,8 @@ if TYPE_CHECKING:
     from .diaglayer import DiagLayer
     from .endofpdufield import EndOfPduField
 
+ParameterDict = Dict[str, Union[Parameter, "ParameterDict"]]
+
 class BasicStructure(DopBase):
     def __init__(self,
                  odx_id,
@@ -37,9 +39,11 @@ class BasicStructure(DopBase):
 
     @property
     def bit_length(self):
+        # Explicit size was specified
         if self._byte_size:
             return 8 * self._byte_size
-        elif all(p.bit_length is not None for p in self.parameters):
+
+        if all(p.bit_length is not None for p in self.parameters):
             offset = 0
             length = 0
             for param in self.parameters:
@@ -57,9 +61,11 @@ class BasicStructure(DopBase):
 
                 length = max(length, offset)
 
-            return length
-        else:
-            return None
+            # Round up to account for padding bits
+            return math.ceil(length / 8) * 8
+
+        # We were not able to calculate a static bit length
+        return None
 
     def coded_const_prefix(self, request_prefix: Union[bytes, bytearray] = bytes()):
         prefix = bytearray()
@@ -179,9 +185,7 @@ class BasicStructure(DopBase):
         if self._byte_size is not None:
             # We definitely broke something if we didn't respect the explicit byte_size
             assert len(coded_rpc) == self._byte_size, self._get_encode_error_str('was', coded_rpc, self._byte_size * 8)
-            # forget what we calcualted, ODX defined an explicit byte_size
-            # if bit_length was less than _byte_size then we have padding or gaps between parameters
-            # if bit_length was more than _byte_size then we over calculated (could happen with overlapping parameters)
+            # No need to check further
             return
 
         bit_length = self.bit_length
@@ -190,13 +194,6 @@ class BasicStructure(DopBase):
             # Nothing to check
             return
 
-        if bit_length % 8 != 0:
-            warnings.warn(
-                f"Structure {self.short_name} length {bit_length} is not divisible by 8, i.e. is not a full sequence of bytes.",
-                OdxWarning)
-            # Round up so not to trigger double alarms
-            bit_length = math.ceil(bit_length / 8) * 8
-
         if len(coded_rpc) * 8 != bit_length:
             # We may have broke something
             # but it could be that bit_length was mis calculated and not the actual bytes are wrong
@@ -253,7 +250,7 @@ class BasicStructure(DopBase):
 
         return param_dict, decode_state.next_byte_position + inner_decode_state.next_byte_position
 
-    def encode(self, coded_request=None, **params) -> bytearray:
+    def encode(self, coded_request: Optional[ByteString] = None, **params) -> ByteString:
         """
         Composes an UDS message as bytes for this service.
         Parameters:
@@ -279,21 +276,25 @@ class BasicStructure(DopBase):
                 f"The message {message.hex()} is longer than could be parsed. Expected {next_byte_position} but got {len(message)}.")
         return param_values
 
-    def parameter_dict(self):
+    def parameter_dict(self) -> ParameterDict:
         """
         Returns a dict with parameter short names as keys.
         The values are parameters for simple types or a nested dict for structures.
         """
-        params = self.parameters
-        assert all(not isinstance(p, ParameterWithDOP) or isinstance(
-            p.dop, DataObjectProperty) or isinstance(p.dop, Structure) for p in self.parameters)
-        param_dict: Dict[str, Union[Parameter, Dict[str, Parameter]]] = {
-            p.short_name: p for p in params
-            if not isinstance(p, ParameterWithDOP) or not isinstance(p.dop, Structure)
+        assert all(not isinstance(p, ParameterWithDOP) or \
+                   isinstance(p.dop, DataObjectProperty) or \
+                   isinstance(p.dop, Structure) for p in self.parameters)
+        param_dict: ParameterDict = {
+            p.short_name: p \
+              for p in self.parameters \
+                if not isinstance(p, ParameterWithDOP) or \
+                   not isinstance(p.dop, Structure)
         }
         param_dict.update({
-            struct_param.short_name: struct_param.dop.parameter_dict()
-            for struct_param in params if isinstance(struct_param, ParameterWithDOP) and isinstance(struct_param.dop, BasicStructure)
+            struct_param.short_name: struct_param.dop.parameter_dict() \
+              for struct_param in self.parameters \
+                if isinstance(struct_param, ParameterWithDOP) and \
+                   isinstance(struct_param.dop, BasicStructure)
         })
         return param_dict
 
@@ -308,7 +309,8 @@ class BasicStructure(DopBase):
             if isinstance(p, TableKeyParameter):
                 p.resolve_references(parent_dl, odxlinks)
 
-    def __message_format_lines(self, allow_unknown_lengths=False):
+    def __message_format_lines(self, allow_unknown_lengths: bool = False) \
+            -> List[str]:
         # sort parameters
         sorted_params: list = list(self.parameters)  # copy list
 
@@ -325,7 +327,7 @@ class BasicStructure(DopBase):
         sorted_params.sort(key=param_sort_key)
 
         # replace structure parameters by their sub parameters
-        params = []
+        params: List[Parameter] = []
         for p in sorted_params:
             if isinstance(p, ValueParameter) and isinstance(p.dop, BasicStructure):
                 params += p.dop.parameters
@@ -368,7 +370,7 @@ class BasicStructure(DopBase):
                     # length, so they need special treatment here
                     dct = None
                     if hasattr(params[i], 'dop'):
-                        dop = params[i].dop
+                        dop = params[i].dop # type: ignore
                         if hasattr(dop, 'diag_coded_type'):
                             dct = dop.diag_coded_type
 
@@ -440,7 +442,7 @@ class BasicStructure(DopBase):
             formatted_lines.append(divide_string)
             return formatted_lines
         else:
-            return None
+            return []
 
     def print_message_format(self, indent: int = 5, allow_unknown_lengths=False):
         """
@@ -499,7 +501,7 @@ class Response(BasicStructure):
                          long_name=long_name, description=description)
         self.response_type = "POS-RESPONSE" if response_type == "POS-RESPONSE" else "NEG-RESPONSE"
 
-    def encode(self, coded_request: bytearray = None, **params):
+    def encode(self, coded_request: Optional[ByteString] = None, **params) -> ByteString:
         logger.info(f"Compose response message to the request {coded_request}")
         if coded_request is not None:
             # Extract MATCHING-REQUEST-PARAMs from the coded request
@@ -524,7 +526,7 @@ class Response(BasicStructure):
 
 def read_structure_from_odx(et_element, doc_frags: List[OdxDocFragment]) -> Union[Structure, Request, Response, None]:
     odx_id = OdxLinkId.from_et(et_element, doc_frags)
-    short_name = et_element.find("SHORT-NAME").text
+    short_name = et_element.findtext("SHORT-NAME")
     long_name = et_element.findtext("LONG-NAME")
     description = read_description_from_odx(et_element.find("DESC"))
     parameters = [read_parameter_from_odx(et_parameter, doc_frags)
@@ -549,8 +551,8 @@ def read_structure_from_odx(et_element, doc_frags: List[OdxDocFragment]) -> Unio
             description=description
         )
     elif et_element.tag == "STRUCTURE":
-        byte_size = int(et_element.find(
-            "BYTE-SIZE").text) if et_element.find("BYTE-SIZE") is not None else None
+        byte_size_text = et_element.findtext("BYTE-SIZE")
+        byte_size = int(byte_size_text) if byte_size_text is not None else None
         res = Structure(
             odx_id,
             short_name,
