@@ -34,7 +34,7 @@ class TableRow:
     description: Optional[str] = None
     semantic: Optional[str] = None
 
-    def __post_init__(self):
+    def __post_init__(self) -> None:
         self._structure: Optional[DopBase] = None
         self._dop: Optional[DopBase] = None
 
@@ -144,7 +144,7 @@ def _get_common_props(et_element, doc_frags: List[OdxDocFragment]):
 def read_table_row_from_odx(et_element, doc_frags: List[OdxDocFragment]) \
     -> TableRow:
     """Reads a TABLE-ROW."""
-    key = et_element.find("KEY").text
+    key = et_element.findtext("KEY")
     structure_ref = None
     if et_element.find("STRUCTURE-REF") is not None:
         structure_ref = OdxLinkRef.from_et(et_element.find("STRUCTURE-REF"), doc_frags)
@@ -163,7 +163,7 @@ def read_table_row_from_odx(et_element, doc_frags: List[OdxDocFragment]) \
 def read_table_from_odx(et_element, doc_frags: List[OdxDocFragment]) \
     -> Table:
     """Reads a TABLE."""
-    short_name = et_element.find("SHORT-NAME").text
+    short_name = et_element.findtext("SHORT-NAME")
     key_dop_ref = None
     if et_element.find("KEY-DOP-REF") is not None:
         key_dop_ref = OdxLinkRef.from_et(et_element.find("KEY-DOP-REF"), doc_frags)
